clc
clear all
close all


% Simulation of resverisble pump turbine (RPT) in pump mode operation
% H and Q-curves from Stranna vs pump model


% Constants:
g = 9.81;


% Parameters from Olimstad's pump turbine
beta2inf = 12.02*pi/180;  % rad
beta1 = 12.8*pi/180;      % rad
B2 = 0.0587;              % [m]
D2 = 0.6305;              % [m]
D1 = 0.349;               % [m]

A1 = pi*(D1/2)^2;         % [m^2]
A2 = pi*D2*B2;            % [m^2]

% Iteration variables:
j = 43;         % Number of measurements in a series
s = 15;         % Number of measurements series per fixed rpm
a = 10;         % Number of files at different rpm
rpm = [290 320 350 380 410 440 470 500 530 560];
%filerpm = 290;  % Lowest rpm
count = 0;




%---------------------------------------------------------------
%% Q, p_2, H and \eta from Stranna's measurements


for a = 1:10           %iteration over different rpm (different files)
    %rpm = filerpm + 30*(a-1);
    filename = ['ed',num2str(rpm(a)),'rpm_xlsx.xlsx'];
    if a==4
        s = 19;        %the last files have 19 measurement series
    end
    [ndata] = xlsread(filename);
    
    for ls = 1:s       %iteration over the measurements series
        for i=1:j      %iteration inside each measurement series
            Q{a}{i, ls} = ndata(i+count,1);           % OK
            H{a}{i, ls} = ndata(i+count,18);          % water head model
            %n{a}{i, ls} = ndata(i+count,9);
            eta{a}{i, ls} = -10000/ndata(i+count,21); % hydraulic eff
            pIn{a}{i, ls} = ndata(i+count,14);        % ok
            pOut{a}{i, ls} = ndata(i+count,15);       % ok
        end
        count = count+45;
        
        Q_avg{a}(ls) = 0;
        H_avg{a}(ls) = 0;
        %n_avg{a}(ls) = 0;
        eta_avg{a}(ls) = 0;
        pIn_avg{a}(ls) = 0;
        pOut_avg{a}(ls) = 0;
        for i = 1:j
            Q_avg{a}(ls) = Q_avg{a}(ls) - Q{a}{i, ls};
            H_avg{a}(ls) = H_avg{a}(ls) + H{a}{i, ls};
            %n_avg{a}(ls) = n_avg{a}(ls) + n{a}{i, ls};
            eta_avg{a}(ls) =  eta_avg{a}(ls) + eta{a}{i, ls};
            pIn_avg{a}(ls) =  pIn_avg{a}(ls) + pIn{a}{i, ls};
            pOut_avg{a}(ls) =  pOut_avg{a}(ls) + pOut{a}{i, ls};
        end
        
        Q_avg{a}(ls) = Q_avg{a}(ls)/j;
        H_avg{a}(ls) = H_avg{a}(ls)/j;
        %n_avg{a}(ls) = n_avg{a}(ls)/j;
        eta_avg{a}(ls) = eta_avg{a}(ls)/j;
        pIn_avg{a}(ls) = pIn_avg{a}(ls)/j;
        pOut_avg{a}(ls) = pOut_avg{a}(ls)/j;
        
        %u2_avg{a}(ls) = pi*D2*n_avg{a}(ls)/60;
        u2_avg(a) = pi*D2*rpm(a)/60;
        Htinf_avg(a,ls) =  u2_avg(a)/g*(u2_avg(a)-Q_avg{a}(ls)/...
            (A2*tan(beta2inf)));

    end
    
    count = 0;
    
    

    
    % Plot efficiency to visualize BEP (best efficiency point)
    figure(1)
    plot(Q_avg{a}(:),eta_avg{a}(:))
    hold on
    
    % Q-H plot
    figure(2)
    plot(Q_avg{a}(:), H_avg{a}(:))
    hold on

    % Q-H and Q-Htinf
    figure(3)
    plot(Q_avg{a}(:), H_avg{a}(:))
    hold on
    plot(Q_avg{a}(:), Htinf_avg(a,:))
    
end

figure(1)
title('')
legend('location', 'eastoutside', 'n = 290 rpm', 'n = 320 rpm',...
    'n = 350 rpm', 'n = 380 rpm', 'n = 410 rpm', 'n = 440 rpm',...
    'n = 470 rpm', 'n = 500 rpm', 'n = 530 rpm', 'n = 560 rpm')
xlabel('Q');
ylabel('\eta');

figure(2)
title('')
legend('location', 'eastoutside', 'n = 290 rpm', 'n = 320 rpm',...
    'n = 350 rpm', 'n = 380 rpm', 'n = 410 rpm', 'n = 440 rpm',...
    'n = 470 rpm', 'n = 500 rpm', 'n = 530 rpm', 'n = 560 rpm')
xlabel('Q')
ylabel('H_p')

figure(3)
title('')
xlabel('Q')
ylabel('H')










%---------------------------------------------------------------
%% Pre-rotation for 560rpm

rho = 998;          % kg/m^3
A1_part = A1/6;     % m^2
A2_part = A2/6;     % m^2


u1 = D1/2*560*2*pi/60;
% u2 = D2/2*560*2*pi/60;


Q_avg_560 = Q_avg{10}(1:19);                % m^3/s
Q_avg_560_part = Q_avg_560./6;              % m^3/s
massflow_560_avgPart = Q_avg_560_part.*rho; % kg/s
vel_560_part = Q_avg_560_part./A1_part;     % m/s
pOut_560 = pOut_avg{end};                   % kPa
pOut2_560 = pOut_560.*1000;                 % Pa


cm1 = vel_560_part;                         % m/s
cm2 = Q_avg_560_part./A2_part;              % m/s


num = 1:19;
oversikt = [num' massflow_560_avgPart' cm1' pOut2_560'];



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% beta_1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


beta1start = atan(cm1./u1);

len = 7;
for i = 1:19
    beta1test{i} = zeros(1,(2*len+1));
    beta1test{i}(1) = beta1start(i);
end


for j = 1:19
    for i = 2:length(beta1test{1})
        if i == length(beta1test{1})/2+1/2
            beta1test{j}(i) = beta1;
        else
            beta1test{j}(i) = beta1test{j}(i-1) + ...
                (beta1 - beta1start(j))/len;
        end
    end
    difftest{j} = beta1test{j}(2:end)-beta1test{j}(1:end-1);
    
    beta1test_double(j) = beta1test{j}(end) + difftest{j}(end)*20;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



for i = 1:19
    cu1{i} = u1 - cm1(i)./tan(beta1test{i});
    
    cu1_double(i) = u1 - cm1(i)./tan(beta1test_double(i));
end




